Rename isOnlyUseOf to isOnlyUserOf.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@54124 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/SelectionDAG/SelectionDAG.cpp b/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
index 4fa5f58..366cb4c4 100644
--- a/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
+++ b/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
@@ -4581,9 +4581,9 @@
 }
 
 
 /// isOnlyUseOf - Return true if this node is the only use of N.
 ///
-bool SDNode::isOnlyUseOf(SDNode *N) const {
+bool SDNode::isOnlyUserOf(SDNode *N) const {
   bool Seen = false;
   for (SDNode::use_iterator I = N->use_begin(), E = N->use_end(); I != E; ++I) {
     SDNode *User = I->getUser();
@@ -4581,9 +4581,9 @@
 
 
-/// isOnlyUseOf - Return true if this node is the only use of N.
+/// isOnlyUserOf - Return true if this node is the only use of N.
 ///